@@ -9,4 +9,6 @@ Created on Mon Jan 10 15:57:46 2022
 from ._qc_plotting import qc_plotting
 from ._gene_density_plot import gene_density_plot
 from ._gene_embedding import gene_embedding
-from ._isoform_qc_plot import isoform_qc_plot
\ No newline at end of file
+from ._isoform_qc_plot import isoform_qc_plot
+from ._gene_heatmap import gene_heatmap
+from ._gene_violinplot import gene_violinplot
\ No newline at end of file
